@@ -1,4 +1,4 @@
-require File.join(File.dirname(__FILE__), "acceptance_test_helper")
+require File.expand_path('../acceptance_test_helper', __FILE__)
 require 'mocha'
 
 class Bug21465Test < Test::Unit::TestCase
@@ -14,7 +14,7 @@ class Bug21465Test < Test::Unit::TestCase
   end
   
   def test_should_allow_expected_method_name_to_be_a_string
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.expects('wibble')
       mock.wibble
@@ -23,7 +23,7 @@ class Bug21465Test < Test::Unit::TestCase
   end
   
   def test_should_allow_stubbed_method_name_to_be_a_string
-    test_result = run_test do
+    test_result = run_as_test do
       mock = mock()
       mock.stubs('wibble')
       mock.wibble
